===============================================
Runana - Run programs and analyse their results
===============================================

Utility library for running programs and analysing their results.

Useful for convergence testing.

Documentation: http://runana.readthedocs.org/en/latest/

Usage
=====

See the examples in the source

Installation
============

``runana`` can be installed from pypi::

   $ pip install runana

The latest version of ``runana`` can be installed from source::

   $ git clone https://github.com/jenssss/runana.git
   $ cd runana
   $ python setup.py install

Users without install privileges can append the ``--user`` flag to
``setup.py``::

   $ python setup.py install --user



   
